@@ -17,8 +17,6 @@ def errormator_tween_factory(handler, registry):
             raise
         except:
             if 'errormator.client' in request.environ:
-                errormator_storage = get_local_storage(local_timing)
-                stats, slow_calls = errormator_storage.get_thread_stats()
                 # pass the traceback object to middleware
                 request.environ['errormator.__traceback'] = get_current_traceback(skip=1,
                                                   show_hidden_frames=True,
